@@ -49,7 +49,7 @@ def retry_n_times(func):
     def func_wrapper(self, *args, **kwargs):
         connection_error = True
         n_tries = 1
-        while connection_error and (n_tries < self.max_retries):
+        while connection_error and (n_tries <= self.max_retries):
             try:
                 r = func(self, *args, **kwargs)
 #               if str(r.status_code)[0] == '2':
@@ -164,7 +164,7 @@ class Client:
                               proxies=self.proxies)
             if r.status_code == 200:
                 self.token = r.json()['access_token']
-                self.token_exp = jwt.decode(self.token, verify=False)['exp']
+                self.token_exp = jwt.decode(self.token, options={"verify_signature": False})['exp']
                 print('Auth in {}s'.format(r.elapsed.total_seconds()))
             else:
                 print('Authentication error: ', r.text)
@@ -177,6 +177,26 @@ class Client:
         auth_header = {'Authorization': 'Bearer {}'.format(self.token)}
         return auth_header
 
+    def manual_request(self, path, method, payload=None):
+        if method.lower() == 'get':
+            r = requests.get('{}/{}'.format(self.api_url, path),
+                              proxies=self.proxies, headers=self.auth_header)
+        elif method.lower() == 'post':
+            r = requests.post('{}/{}'.format(self.api_url, path),
+                              json=payload, proxies=self.proxies, headers=self.auth_header)
+        elif method.lower() == 'delete':
+            r = requests.delete('{}/{}'.format(self.api_url, path),
+                              proxies=self.proxies, headers=self.auth_header)
+        elif method.lower() == 'put':
+            r = requests.put('{}/{}'.format(self.api_url, path),
+                              proxies=self.proxies, headers=self.auth_header)
+        elif method.lower() == 'options':
+            r = requests.put('{}/{}'.format(self.api_url, path),
+                              proxies=self.proxies, headers=self.auth_header)
+        else:
+            raise NotImplementedError('Unknown http method: {}'.format(method))
+        return r
+
     def create_user(self, email, password, first_name, last_name):
         data = {'email': email, 'password': password,
                 'first_name': first_name, 'last_name': last_name}
@@ -212,11 +232,11 @@ class Client:
                          headers=self.auth_header, proxies=self.proxies)
         return r
 
-    def SubmitJob(self, object_class, id_, method, arguments=None):
+    def object_method(self, object_class, object_id, method, arguments=None):
         if arguments is None:
             arguments = {}
         serialized_arguments = dc.serialize_dict(arguments)
-        data = {'object': {'object_class': object_class, 'id': id_},
+        data = {'object': {'object_class': object_class, 'object_id': object_id},
                 'method': method, 'method_dict': serialized_arguments}
         r = requests.post('{}/jobs/submit'.format(self.api_url), json=data,
                           headers=self.auth_header, proxies=self.proxies)
